# CLI Tools Documentation Index

This directory contains help documentation for various command-line tools used in development.

## Rust CLI Tools

### File and Text Operations
- **curl.txt** - HTTP client with better output formatting than system curl
- **jq.txt** - JSON processor for parsing and manipulating JSON data
- **rg.txt** - ripgrep - Fast text search tool (alternative to grep)
- **fd.txt** - Fast file finder (alternative to find)
- **htmlq.txt** - HTML parser and selector tool for web scraping

### Development Tools
- **hyperfine.txt** - Command-line benchmarking tool for performance testing
- **broot.txt** - Interactive directory tree navigation
- **mise.txt** - Development environment and version manager
- **llm.txt** - Command-line interface for various language models
- **monolith.txt** - Tool for saving complete web pages as single HTML files
- **rnr.txt** - Bulk file renaming utility with regex support
- **tspin.txt** - Log file viewer with syntax highlighting and filtering

### Media Processing
- **convert.txt** - ImageMagick's image manipulation and conversion tool
- **ffmpeg.txt** - Video and audio processing
- **sox.txt** - Audio file manipulation
- **yt-dlp.txt** - YouTube and video platform downloader
- **audacity.txt** - Note about GUI audio editing tool (no CLI)

## Python Development Tools
- **click.txt** - Python CLI creation framework
- **pytest.txt** - Python testing framework
- **ruff.txt** - Python linter and formatter
- **pydantic.txt** - Data validation library
- **pydantic-ai.txt** - AI agent framework with structured output

## Web and Data Tools
- **fasthtml.txt** - Fast HTML framework
- **jinja2.txt** - Template engine
- **rich.txt** - Rich text and beautiful formatting in terminal
- **prompt-toolkit.txt** - Interactive command line applications
- **numpy.txt** - Numerical computing library
- **plotly.txt** - Interactive graphing library
- **streamlit.txt** - Data app framework

## Notes
- Tools marked as "not installed" in their documentation files were not available on the system at the time of documentation generation.
- All documentation was generated on: Thu Jul 10 2025
- For tools with extensive help systems, basic help output was captured. Many tools support additional detailed help via subcommands.